var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
/**
 * Copyright 2019 Justin Fagnani <justin@fagnani.com>
 */
import { LitElement, html, css, property, customElement, query } from 'lit-element';
import './pdf-viewer-display.js';
import '@material/mwc-fab';
import '@material/mwc-icon-button';
/**
 * A web component that displays PDFs
 *
 * @cssprop [--pdf-viewer-top-bar-height=48px]
 * @cssprop [--pdf-viewer-page-shadow=2px 2px 2px 1px rgba(0, 0, 0, 0.2)]
 * @cssprop [--pdf-viewer-background=gray]
 */
let PDFViewerElement = class PDFViewerElement extends LitElement {
    constructor() {
        super(...arguments);
        /**
         * The current 1-based page number.
         */
        this.page = 1;
        /**
         * Whether multiple pages should render. Single page rendering is much faster.
         */
        this.multiPage = false;
        this.scale = 'cover';
        this.zoom = 1;
    }
    /**
     * Total page count of the current document.
     */
    get pageCount() {
        var _a, _b;
        return (_b = (_a = this._display) === null || _a === void 0 ? void 0 : _a.pageCount) !== null && _b !== void 0 ? _b : 0;
    }
    get documentTitle() {
        var _a, _b;
        return (_b = (_a = this._display) === null || _a === void 0 ? void 0 : _a.documentTitle) !== null && _b !== void 0 ? _b : '';
    }
    render() {
        return html `
      <div id="top-bar">
        <span id="">
          <!-- <mwc-icon-button id="drawer"
            icon="menu" 
            mini>
          </mwc-icon-button> -->
        </span>
        <span id="title">${this.documentTitle}</span>
        <span id="nav">
          <mwc-icon-button id="prev"
            icon="navigate_before" 
            mini
            @click=${this.previousPage}>
          </mwc-icon-button>
          <span id="page-number">${this.page} / ${this.pageCount}</span>
          <mwc-icon-button id="next"
              icon="navigate_next" 
              mini
              @click=${this.nextPage}>
          </mwc-icon-button>
        </span>
      </div>
      <pdf-viewer-display
        .src=${this.src}
        .page=${this.page}
        .multiPage=${this.multiPage}
        .scale=${this.scale}
        .zoom=${this.zoom}
        .documentTitle=${this.documentTitle}
        @load=${this._onLoad}
      ></pdf-viewer-display>
      <div id="controls">
        <mwc-fab id="zoom-out"
            icon="remove"
            mini
            @click=${this.zoomOut}>
        </mwc-fab>
        <mwc-fab id="zoom-in"
            icon="add"
            mini
            @click=${this.zoomIn}>
        </mwc-fab>
      </div>`;
    }
    _onLoad() {
        console.log('_onLoad');
        this.requestUpdate();
    }
    zoomOut() {
        this.zoom = Math.max(this.zoom - .25, .25);
    }
    zoomIn() {
        // TODO: what's the max zoom?
        this.zoom += .25;
    }
    nextPage() {
        if (this.page < this.pageCount) {
            this.page++;
        }
    }
    previousPage() {
        if (this.page > 1) {
            this.page--;
        }
    }
};
PDFViewerElement.styles = css `
    :host {
      display: flex;
      flex-direction: column;
      position: relative;
      --mdc-theme-primary: var(--mdc-theme-primary, #37474f);
      --mdc-theme-on-primary: var(--mdc-theme-on-primary, white);
      --mdc-theme-secondary: white;
      --mdc-theme-on-secondary: black;
      --pdf-viewer-top-bar-height: 48px;
      --pdf-viewer-page-shadow: 2px 2px 2px 1px rgba(0, 0, 0, 0.2);
    }
    pdf-viewer-display {
      width: 100%;
      height: 100%;
    }
    #controls {
      display: block;
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      user-select: none;
      pointer-events: none;
    }
    #controls > * {
      user-select: initial;
      pointer-events: initial;
    }
    #top-bar {
      top: 0;
      height: var(--pdf-viewer-top-bar-height);
      display: flex;
      flex-direction: row;
      justify-content: center;
      align-items: center;
      color: var(--mdc-theme-on-primary, white);
      background: var(--mdc-theme-primary, #37474f);
      /* From https://github.com/material-components/material-components-web/blob/8d8f3fcb3f2940b071f761497490c1b0123e106b/packages/mdc-typography/_variables.scss */
      font-family: Roboto, sans-serif;
      font-size: 1rem;
      line-height: 2rem;
      font-weight: medium;
      letter-spacing: 1.25;
      /* 10px is the same as the content margin */
      padding: 0 10px;
    }
    #top-bar > * {
      flex: 1;
    }
    #page-number {
      text-align: center;
      vertical-align: middle;
    }
    #nav {
      text-align: right;
      --mdc-icon-button-size: 36px;
    }
    #title {
      text-align: center;
    }
    #zoom-out {
      position: absolute;
      bottom: 50px;
      right: 40px;
    }
    #zoom-in {
      position: absolute;
      bottom: 100px;
      right: 40px;
    }
  `;
__decorate([
    query('pdf-viewer-display')
], PDFViewerElement.prototype, "_display", void 0);
__decorate([
    property({ type: String, reflect: true })
], PDFViewerElement.prototype, "src", void 0);
__decorate([
    property({ type: Number, reflect: true })
], PDFViewerElement.prototype, "page", void 0);
__decorate([
    property({
        attribute: 'multi-page',
        type: Boolean,
        reflect: true,
    })
], PDFViewerElement.prototype, "multiPage", void 0);
__decorate([
    property({
        reflect: true,
    })
], PDFViewerElement.prototype, "scale", void 0);
__decorate([
    property({ type: Number, reflect: true })
], PDFViewerElement.prototype, "zoom", void 0);
PDFViewerElement = __decorate([
    customElement('pdf-viewer')
], PDFViewerElement);
export { PDFViewerElement };
//# sourceMappingURL=pdf-viewer.js.map